@@ -15,17 +15,20 @@
 """AgentKit CLI - Invoke command implementation."""
 
 from pathlib import Path
-from typing import Optional, Any, List
+from typing import Optional, Any
 import json
 import typer
 from rich.console import Console
 import random
+import uuid
 from agentkit.toolkit.config import get_config
+import logging
 
-# Note: 不要在文件开头导很重的包，不然会导致命令很卡(import包很慢)
-
+# Note: Avoid importing heavy packages at the top to keep CLI startup fast
+logger = logging.getLogger(__name__)
 console = Console()
 
+
 def build_standard_payload(message: Optional[str], payload: Optional[str]) -> dict:
     if message:
         return {"prompt": message}
@@ -38,7 +41,10 @@ def build_standard_payload(message: Optional[str], payload: Optional[str]) -> di
             console.print(f"[red]Error: Invalid JSON payload: {e}[/red]")
             raise typer.Exit(1)
 
-def build_a2a_payload(message: Optional[str], payload: Optional[str], headers: dict) -> dict:
+
+def build_a2a_payload(
+    message: Optional[str], payload: Optional[str], headers: dict
+) -> dict:
     parsed = None
     if payload:
         try:
@@ -63,16 +69,16 @@ def build_a2a_payload(message: Optional[str], payload: Optional[str], headers: d
         "params": {
             "message": {
                 "role": "user",
-                "parts": [
-                    {"kind": "text", "text": text}
-                ]
+                "messageId": str(uuid.uuid4()),
+                "parts": [{"kind": "text", "text": text}],
             },
-            "metadata": headers
+            "metadata": headers,
         },
-        "id": random.randint(1, 999999)
+        "id": random.randint(1, 999999),
     }
     return a2a
 
+
 def invoke_command(
     config_file: Path = typer.Option("agentkit.yaml", help="Configuration file"),
     message: str = typer.Argument(None, help="Simple message to send to agent"),
@@ -87,45 +93,44 @@ def invoke_command(
     ),
 ) -> Any:
     """Send a test request to deployed Agent.
-    
+
     Examples:
         # Simple message
-        agentkit invoke "今天天气如何？"
-        
+        agentkit invoke "What is the weather today?"
+
         # Custom payload
-        agentkit invoke --payload '{"prompt": "杭州天气?"}'
-        
+        agentkit invoke --payload '{"prompt": "What is the weather in Hangzhou?"}'
+
         # With custom headers
-        agentkit invoke --payload '{"prompt": "杭州天气?"}' --headers '{"user_id": "test123"}'
+        agentkit invoke --payload '{"prompt": "What is the weather in Hangzhou?"}' --headers '{"user_id": "test123"}'
     """
-    from agentkit.toolkit import sdk
+    from agentkit.toolkit.executors import InvokeExecutor
+    from agentkit.toolkit.cli.console_reporter import ConsoleReporter
 
     console.print("[cyan]Invoking agent...[/cyan]")
-    
-    # 验证参数：message和payload不能同时提供
+
+    # Validate parameters: message and payload cannot be provided simultaneously
     if message and payload:
-        console.print("[red]Error: Cannot specify both message and payload. Use either message or --payload.[/red]")
+        console.print(
+            "[red]Error: Cannot specify both message and payload. Use either message or --payload.[/red]"
+        )
         raise typer.Exit(1)
-    
-    # 验证参数：必须提供message或payload
+
+    # Validate parameters: must provide either message or payload
     if not message and not payload:
-        console.print("[red]Error: Must provide either a message or --payload option.[/red]")
+        console.print(
+            "[red]Error: Must provide either a message or --payload option.[/red]"
+        )
         raise typer.Exit(1)
 
     config = get_config(config_path=config_file)
     common_config = config.get_common_config()
-    
-    final_payload = build_standard_payload(message, payload)
-    agent_type = getattr(common_config, "agent_type", "") or getattr(common_config, "template_type", "")
-    is_a2a = isinstance(agent_type, str) and "a2a" in agent_type.lower()
 
-    # 如果是 A2A Agent，则用 A2A 构造函数重建 payload
-    if is_a2a:
-        console.print("[cyan]Detected A2A agent type - constructing A2A JSON-RPC envelope[/cyan]")
-        final_payload = build_a2a_payload(message, payload, final_headers)
-
-    # 处理headers
-    final_headers = {"user_id": "agentkit_user", "session_id": "agentkit_sample_session"}
+    # Process headers
+    final_headers = {
+        "user_id": "agentkit_user",
+        "session_id": "agentkit_sample_session",
+    }
     if headers:
         try:
             final_headers = json.loads(headers) if isinstance(headers, str) else headers
@@ -135,47 +140,66 @@ def invoke_command(
             raise typer.Exit(1)
     else:
         console.print(f"[blue]Using default headers: {final_headers}[/blue]")
-    
-    # Call SDK
-    result = sdk.invoke(
+
+    final_payload = build_standard_payload(message, payload)
+    agent_type = getattr(common_config, "agent_type", "") or getattr(
+        common_config, "template_type", ""
+    )
+    is_a2a = isinstance(agent_type, str) and "a2a" in agent_type.lower()
+
+    # If it's an A2A Agent, reconstruct payload using A2A constructor
+    if is_a2a:
+        console.print(
+            "[cyan]Detected A2A agent type - constructing A2A JSON-RPC envelope[/cyan]"
+        )
+        final_payload = build_a2a_payload(message, payload, final_headers)
+
+    # Set execution context - CLI uses ConsoleReporter (with colored output and progress)
+    from agentkit.toolkit.context import ExecutionContext
+
+    reporter = ConsoleReporter()
+    ExecutionContext.set_reporter(reporter)
+
+    executor = InvokeExecutor(reporter=reporter)
+    result = executor.execute(
         payload=final_payload,
         config_file=str(config_file),
         headers=final_headers,
-        apikey=apikey
+        stream=None,  # Automatically determined by Runner
     )
-    
+
     if not result.success:
         console.print(f"[red]❌ Invocation failed: {result.error}[/red]")
         raise typer.Exit(1)
-    
+
     console.print("[green]✅ Invocation successful[/green]")
 
     # Get response
     response = result.response
 
-    # 处理流式响应（生成器）
+    # Handle streaming response (generator)
     if result.is_streaming:
         console.print("[cyan]📡 Streaming response detected...[/cyan]\n")
         result_list = []
         complete_text = []
-        
+
         for event in result.stream():
             result_list.append(event)
-            
-            # 如果是字符串且以 "data: " 开头，尝试解析（fallback处理）
+
+            # If it's a string starting with "data: ", try to parse (fallback handling)
             if isinstance(event, str):
                 if event.strip().startswith("data: "):
                     try:
-                        json_str = event.strip()[6:].strip()  # 移除 "data: " 前缀
+                        json_str = event.strip()[6:].strip()  # Remove "data: " prefix
                         event = json.loads(json_str)
                     except json.JSONDecodeError:
-                        # 解析失败，跳过此事件
+                        # Parsing failed, skip this event
                         continue
                 else:
-                    # 不是 SSE 格式的字符串，跳过
+                    # Not SSE format string, skip
                     continue
-            
-            # 处理 A2A JSON-RPC
+
+            # Handle A2A JSON-RPC
             if isinstance(event, dict) and event.get("jsonrpc") and "result" in event:
                 event = event["result"]
 
@@ -187,6 +211,13 @@ def invoke_command(
                     parts = event["message"].get("parts", [])
                 elif isinstance(event.get("content"), dict):
                     parts = event["content"].get("parts", [])
+                elif isinstance(event.get("status"), dict):
+                    role = event["status"].get("message", {}).get("role")
+                    if role == "agent":
+                        parts = event["status"].get("message", {}).get("parts", [])
+                if not event.get("partial", True):
+                    logger.info("Partial event: %s", event)  # Log partial events
+                    continue
 
                 if parts:
                     for p in parts:
@@ -197,16 +228,15 @@ def invoke_command(
                             text = p
                         if text:
                             complete_text.append(text)
-                            # 增量打印（保持不换行）
+                            # Incremental print (keep no newline)
                             console.print(text, end="", style="green")
 
-                # 显示事件中的错误信息（如果有）
+                # Display error information in event (if any)
                 if "error" in event:
                     console.print(f"\n[red]Error: {event['error']}[/red]")
 
-                # 处理状态更新（例如 final 标志或 completed 状态）
+                # Handle status updates (e.g., final flag or completed status)
                 if event.get("final") is True:
-                    console.print("\n[cyan]Stream marked final[/cyan]")
                     break
 
                 status = event.get("status")
@@ -214,19 +244,19 @@ def invoke_command(
                     console.print("\n[cyan]Status indicates completed[/cyan]")
                     break
 
-        # # 显示完整响应
+        # Display complete response (commented out for now)
         # if complete_text:
         #     console.print("\n\n[cyan]━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━[/cyan]")
         #     console.print(f"[cyan]📝 Complete response:[/cyan] {''.join(complete_text)}")
-        console.print("")   # line break
-        
+        console.print("")  # Line break
+
         return str(result_list)
-    
-    # 处理非流式响应
+
+    # Handle non-streaming response
     console.print("[cyan]📝 Response:[/cyan]")
     if isinstance(response, dict):
         console.print(json.dumps(response, indent=2, ensure_ascii=False))
     else:
         console.print(response)
-    
-    return str(response)
\ No newline at end of file
+
+    return str(response)
